pub struct Reports {
pub reports: DenseSlotMap<ReportId, Report>,
}Fields
reports: DenseSlotMap<ReportId, Report>Implementations
Methods from Deref<Target = DenseSlotMap<ReportId, Report>>
Sourcepub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of elements in the slot map.
Examples
let mut sm = DenseSlotMap::with_capacity(10);
sm.insert("len() counts actual elements, not capacity");
let key = sm.insert("removed elements don't count either");
sm.remove(key);
assert_eq!(sm.len(), 1);Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns if the slot map is empty.
Examples
let mut sm = DenseSlotMap::new();
let key = sm.insert("dummy");
assert_eq!(sm.is_empty(), false);
sm.remove(key);
assert_eq!(sm.is_empty(), true);Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the number of elements the DenseSlotMap can hold without
reallocating.
Examples
let sm: DenseSlotMap<_, f64> = DenseSlotMap::with_capacity(10);
assert_eq!(sm.capacity(), 10);Sourcepub fn contains_key(&self, key: K) -> bool
pub fn contains_key(&self, key: K) -> bool
Sourcepub fn get(&self, key: K) -> Option<&V>
pub fn get(&self, key: K) -> Option<&V>
Returns a reference to the value corresponding to the key.
Examples
let mut sm = DenseSlotMap::new();
let key = sm.insert("bar");
assert_eq!(sm.get(key), Some(&"bar"));
sm.remove(key);
assert_eq!(sm.get(key), None);Sourcepub unsafe fn get_unchecked(&self, key: K) -> &V
pub unsafe fn get_unchecked(&self, key: K) -> &V
Returns a reference to the value corresponding to the key without version or bounds checking.
Safety
This should only be used if contains_key(key) is true. Otherwise it is
potentially unsafe.
Examples
let mut sm = DenseSlotMap::new();
let key = sm.insert("bar");
assert_eq!(unsafe { sm.get_unchecked(key) }, &"bar");
sm.remove(key);
// sm.get_unchecked(key) is now dangerous!Sourcepub fn iter(&self) -> Iter<'_, K, V>
pub fn iter(&self) -> Iter<'_, K, V>
An iterator visiting all key-value pairs in an arbitrary order. The
iterator element type is (K, &'a V).
Examples
let mut sm = DenseSlotMap::new();
let k0 = sm.insert(0);
let k1 = sm.insert(1);
let k2 = sm.insert(2);
let mut it = sm.iter();
for (k, v) in sm.iter() {
println!("key: {:?}, val: {}", k, v);
}Sourcepub fn keys(&self) -> Keys<'_, K, V>
pub fn keys(&self) -> Keys<'_, K, V>
An iterator visiting all keys in an arbitrary order. The iterator element type is K.
Examples
let mut sm = DenseSlotMap::new();
let k0 = sm.insert(10);
let k1 = sm.insert(20);
let k2 = sm.insert(30);
let keys: HashSet<_> = sm.keys().collect();
let check: HashSet<_> = vec![k0, k1, k2].into_iter().collect();
assert_eq!(keys, check);Sourcepub fn values(&self) -> Values<'_, K, V>
pub fn values(&self) -> Values<'_, K, V>
An iterator visiting all values in an arbitrary order. The iterator
element type is &'a V.
Examples
let mut sm = DenseSlotMap::new();
let k0 = sm.insert(10);
let k1 = sm.insert(20);
let k2 = sm.insert(30);
let values: HashSet<_> = sm.values().collect();
let check: HashSet<_> = vec![&10, &20, &30].into_iter().collect();
assert_eq!(values, check);Sourcepub fn keys_as_slice(&self) -> &[K]
pub fn keys_as_slice(&self) -> &[K]
Returns a slice containing all keys in the slot map in an arbitrary
order (but in the same order as
values_as_slice).
Examples
let mut sm = DenseSlotMap::new();
let k1 = sm.insert(1);
let k2 = sm.insert(2);
sm.remove(k1);
sm.insert(3);
let key_slice = sm.keys_as_slice();
// The order is arbitrary, but we can check if the keys are present.
assert!(key_slice.contains(&k2));
assert_eq!(key_slice.len(), 2);
// The keys correspond to the values.
assert_eq!(sm.values_as_slice()[0], sm[key_slice[0]]);Sourcepub fn values_as_slice(&self) -> &[V]
pub fn values_as_slice(&self) -> &[V]
Returns a slice containing all values in the slot map in an arbitrary
order (but in the same order as keys_as_slice).
Examples
let mut sm = DenseSlotMap::new();
sm.insert(10);
sm.insert(20);
sm.insert(30);
let value_slice = sm.values_as_slice();
let values: HashSet<_> = value_slice.iter().collect();
let check: HashSet<_> = vec![&10, &20, &30].into_iter().collect();
assert_eq!(values, check);
// The keys correspond to the values.
assert_eq!(value_slice[0], sm[sm.keys_as_slice()[0]]);Sourcepub fn as_slices(&self) -> (&[K], &[V])
pub fn as_slices(&self) -> (&[K], &[V])
Returns slices containing all keys and values in the slot map in an arbitrary order (but in the same order for both slices).
Examples
let mut sm = DenseSlotMap::new();
sm.insert(10);
sm.insert(8);
sm.insert(6);
let (keys, values) = sm.as_slices();
for (k, v) in keys.iter().zip(values) {
assert_eq!(sm[*k], *v);
}Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Reports
impl<'de> Deserialize<'de> for Reports
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,